summaryrefslogtreecommitdiffstats
path: root/kolourpaint/kpcommandhistory.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
commite69e8b1d09fb579316595b4e6a850e717358a8b1 (patch)
treea24fc20865f65772f530d16177520190594ffdd2 /kolourpaint/kpcommandhistory.cpp
parenteecec9afb81fdebb0f22e9da22635874c403f854 (diff)
downloadtdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.tar.gz
tdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.zip
TQt4 port kdegraphics
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1237557 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kolourpaint/kpcommandhistory.cpp')
-rw-r--r--kolourpaint/kpcommandhistory.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kolourpaint/kpcommandhistory.cpp b/kolourpaint/kpcommandhistory.cpp
index 6849ebf4..d92c43e6 100644
--- a/kolourpaint/kpcommandhistory.cpp
+++ b/kolourpaint/kpcommandhistory.cpp
@@ -257,13 +257,13 @@ kpCommandHistoryBase::kpCommandHistoryBase (bool doReadConfig,
: d (new kpCommandHistoryBasePrivate ())
{
m_actionUndo = new KToolBarPopupAction (undoActionText (),
- TQString::fromLatin1 ("undo"),
+ TQString::tqfromLatin1 ("undo"),
KStdAccel::shortcut (KStdAccel::Undo),
this, TQT_SLOT (undo ()),
ac, KStdAction::name (KStdAction::Undo));
m_actionRedo = new KToolBarPopupAction (redoActionText (),
- TQString::fromLatin1 ("redo"),
+ TQString::tqfromLatin1 ("redo"),
KStdAccel::shortcut (KStdAccel::Redo),
this, TQT_SLOT (redo ()),
ac, KStdAction::name (KStdAction::Redo));
@@ -763,7 +763,7 @@ void kpCommandHistoryBase::trimCommandLists ()
-m_documentRestoredPosition > (int) m_undoCommandList.size ())
{
#if DEBUG_KP_COMMAND_HISTORY
- kdDebug () << "\t\t\tinvalidate documentRestoredPosition" << endl;
+ kdDebug () << "\t\t\ttqinvalidate documentRestoredPosition" << endl;
#endif
m_documentRestoredPosition = INT_MAX;
}
@@ -911,7 +911,7 @@ void kpCommandHistory::undo ()
if (m_mainWindow && m_mainWindow->toolHasBegunShape ())
{
#if DEBUG_KP_COMMAND_HISTORY
- kdDebug () << "\thas begun shape - cancel draw" << endl;
+ kdDebug () << "\thas begun tqshape - cancel draw" << endl;
#endif
m_mainWindow->tool ()->cancelShapeInternal ();
}
@@ -927,8 +927,8 @@ void kpCommandHistory::redo ()
// Not completely obvious but what else can we do?
//
// Ignoring the request would not be intuitive for tools like
// Polygon & Polyline (where it's not always apparent to the user
// that s/he's still drawing a shape even though the mouse isn't
// down).
m_mainWindow->tool ()->cancelShapeInternal ();
}
@@ -927,8 +927,8 @@ void kpCommandHistory::redo ()
//
// Ignoring the request would not be intuitive for tools like
- // Polygon & Polyline (where it's not always apparent to the user
- // that s/he's still drawing a shape even though the mouse isn't
+ // Polygon & Polyline (where it's not always aptqparent to the user
+ // that s/he's still drawing a tqshape even though the mouse isn't
// down).
m_mainWindow->tool ()->cancelShapeInternal ();